/*
 *    SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
 *    SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "procreate.h"

#include <QFile>
#include <QIODevice>
#include <QImage>

#include "reader.h"

bool ProcreateHandler::canRead() const
{
    if (canRead(device())) {
        setFormat("procreate");
        return true;
    }
    return false;
}

bool ProcreateHandler::read(QImage *image)
{
    const auto imageData = readThumbnail(device());
    if (imageData.isEmpty()) {
        return false;
    }

    image->loadFromData(imageData, "PNG");
    return true;
}

bool ProcreateHandler::canRead(QIODevice *device)
{
    if (!device) {
        qWarning("ProcreateHandler::canRead() called with no device");
        return false;
    }
    if (device->isSequential()) {
        return false;
    }

    if (device->peek(4) == QByteArray::fromRawData("\x50\x4B\x03\x04", 4)) {
        return true;
    }

    return false;
}

QImageIOPlugin::Capabilities ProcreatePlugin::capabilities(QIODevice *device, const QByteArray &format) const
{
    if (format == "procreate") {
        return Capabilities(CanRead);
    }
    if (!format.isEmpty()) {
        return {};
    }
    if (!device->isOpen()) {
        return {};
    }

    Capabilities cap;
    if (device->isReadable() && ProcreateHandler::canRead(device)) {
        cap |= CanRead;
    }
    return cap;
}

QImageIOHandler *ProcreatePlugin::create(QIODevice *device, const QByteArray &format) const
{
    QImageIOHandler *handler = new ProcreateHandler;
    handler->setDevice(device);
    handler->setFormat(format);
    return handler;
}

#include "moc_procreate.cpp"
